@@ -5,6 +5,8 @@ from typing import List, Dict
 import numpy as np
 import argparse
 
+from hpogrid.utils.cli_parser import CLIParser
+
 kDefaultGenerator = 'nevergrad'
 kDefaultMetric = 'loss'
 kDefaultMode = 'min'
@@ -23,13 +25,16 @@ class NpEncoder(json.JSONEncoder):
             return super(NpEncoder, self).default(obj)
 
 class SteeringIDDS():
-    def __init__(self, parse=True):
-        if (len(sys.argv) > 1) and parse:
-            self.run_parser()
+    
+    _USAGE_ = 'hpogrid generate [<args>]'
+    _DESCRIPTION_ = 'Tool for generation of hyperparamter search points based on input search space'
+    
+    def __init__(self):
+        pass
 
-    def get_parser(self):
-        parser = argparse.ArgumentParser(
-                    formatter_class=argparse.RawDescriptionHelpFormatter)
+    def get_parser(self, **kwargs):
+        parser = CLIParser(description=self._DESCRIPTION_,
+                           usage=self._USAGE_, **kwargs) 
         parser.add_argument('-l', '--lib', default=kDefaultGenerator,
             help='library to use')  
         parser.add_argument('-s', '--space',
@@ -45,7 +50,13 @@ class SteeringIDDS():
         parser.add_argument('-i', '--infile', help='iDDS input')
         parser.add_argument('-o', '--outfile', help='iDDS output')
         parser.add_argument('--method', help='optimizer type (nevergrad only)')
-        return parser  
+        return parser
+    
+    def run_parser(self, args=None):
+        parser = self.get_parser()
+        args, extra = parser.parse_known_args(args)
+        args = vars(args)
+        self.run_generator(**args)    
 
     def get_generator(self, space, metric=kDefaultMetric, mode=kDefaultMode, lib=kDefaultGenerator, **args):
         if lib == 'nevergrad':
@@ -69,14 +80,6 @@ class SteeringIDDS():
         else:
             raise ValueError('Generator from library {} is not supported'.format(lib))
 
-    def run_parser(self):
-        parser = self.get_parser()
-        if os.path.basename(sys.argv[0]) == 'hpogrid':
-            args = parser.parse_args(sys.argv[2:])
-        else:
-            args = parser.parse_args(sys.argv[1:])
-        self.run_generator(**vars(args))
-
     def validate_idds_input(self, idds_input):
         '''
         old format
@@ -144,10 +147,10 @@ class SteeringIDDS():
                 model_results[model_id]['points'] = []
                 model_results[model_id]['results'] = []
             for data in idds_data.get('points', []):
-                model_id = data[0]
+                model_id = data[0][0]
                 if model_id not in model_results:
                     raise ValueError('missing search space definition for model id: {}'.format(model_id))
-                point, result = data[1], data[2]
+                point, result = data[0][1], data[1]
                 model_results[model_id]['points'].append(point)
                 model_results[model_id]['results'].append(result)
             return model_results
@@ -230,7 +233,8 @@ class SteeringIDDS():
                                                                 metric=metric, mode=mode,
                                                                 lib=lib, max_point=max_point, 
                                                                 points=points, results=results, **args)
-                new_points.append(tuple([model_id, model_specific_new_points]))
+                for point in model_specific_new_points:
+                    new_points.append(tuple([model_id, point]))
 
         # save output
         if outfile:
